﻿namespace UltraGridMergeCells
{
    using System.Drawing;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinGrid;

    internal class DF : IUIElementDrawFilter
    {
        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            //  If element is text element we need and its parent's parent is merged cell
            //  element draw the text in vertical direction and supress default drawing
            var textElement = drawParams.Element as EditorWithTextDisplayTextUIElement;
            if(textElement != null &&
               textElement.Parent != null &&
               textElement.Parent.Parent != null &&
               textElement.Parent.Parent is MergedCellUIElement)
            {
                var sf = new StringFormat(StringFormatFlags.DirectionVertical);
                sf.Alignment = StringAlignment.Center;
                sf.LineAlignment = StringAlignment.Center;
                drawParams.Graphics.DrawString(textElement.Text, textElement.Control.Font, Brushes.Black, textElement.Rect, sf);
                return true;
            }

            //  In all other cases let default drawing of the text to be completed
            return false;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            //  If element is text element we need return before the element's text is drawn
            if(drawParams.Element is EditorWithTextDisplayTextUIElement)
            {
                return DrawPhase.BeforeDrawForeground;
            }

            return DrawPhase.None;
        }
    }
}
